@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
+from django.templatetags.static import static
 from django.utils.translation import ugettext_lazy as _
 
 from .models import HighlightText
@@ -21,4 +22,7 @@ class HighlightPlugin(CMSPluginBase):
             'highlight': 'djangocms_highlightjs/js/highlight.pack.js'
         })
         return context
+
+    def icon_src(self, instance):
+        return static('djangocms_highlightjs/img/icon.png')
 plugin_pool.register_plugin(HighlightPlugin)
